==> foundation-2.6.1.tgz: package/ResultsDemographics/ResultsDemographics.esm.js <==
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export const ResultsDemographics = /*#__PURE__*/React.forwardRef((props, ref) => {
  const attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, Object.assign({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M27.953 46.506a21.02 21.02 0 01-2.117-9.192c0-1.743.252-3.534.768-5.468.231-.87.521-1.702.847-2.509-1.251-.683-2.626-1.103-4.101-1.103-5.47 0-9.898 5.153-9.898 11.517 0 4.452 2.176 8.305 5.354 10.222L5.391 56.217c-.836.393-1.387 1.337-1.387 2.392v10.588c0 1.419.991 2.569 2.21 2.569h7.929v-11.11c0-3.237 1.802-6.172 4.599-7.481l10.262-4.779a20.2 20.2 0 01-1.051-1.89zm32.184-11.705h34.092V34.8l.006.001c.973 0 1.761-.789 1.761-1.761v-6.431c0-.973-.789-1.761-1.761-1.761l-.006.001v-.005H56.133a20.013 20.013 0 013.526 7.435c.215.889.371 1.72.478 2.522zm35.859 31.635c0-.973-.789-1.761-1.761-1.761l-.006.001v-.005H72.007v9.089c0 .293-.016.582-.045.867h22.267v-.001l.006.001c.973 0 1.761-.789 1.761-1.761v-6.43zm-1.761-21.674l-.006.001v-.005H58.944c-.159.419-.327.836-.514 1.249a20.258 20.258 0 01-1.224 2.297l10.288 4.908a7.67 7.67 0 012.078 1.503h24.657v-.001l.006.001c.973 0 1.761-.789 1.761-1.761v-6.431c0-.973-.789-1.761-1.761-1.761z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M65.323 57.702l-11.551-5.51-4.885-2.33c2.134-1.344 3.866-3.418 5-5.917a16.045 16.045 0 001.435-6.631c0-1.348-.213-2.627-.512-3.863-1.453-5.983-6.126-10.392-11.736-10.392-5.504 0-10.106 4.251-11.648 10.065-.356 1.333-.602 2.72-.602 4.189 0 2.552.596 4.93 1.609 7 1.171 2.4 2.906 4.379 5.018 5.651l-4.678 2.178-11.926 5.554c-1.037.485-1.717 1.654-1.717 2.959V73.76c0 1.756 1.224 3.181 2.735 3.181h42.417c1.511 0 2.735-1.424 2.735-3.181V60.656c.002-1.301-.668-2.458-1.694-2.954z"
  }));
});
ResultsDemographics.displayName = 'ResultsDemographics';
export const ResultsDemographicsDimensions = {
  height: 100,
  width: 100
};

==> foundation-2.7.1.tgz: package/ResultsDemographics/ResultsDemographics.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var ResultsDemographics = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M27.953 46.506a21.02 21.02 0 01-2.117-9.192c0-1.743.252-3.534.768-5.468.231-.87.521-1.702.847-2.509-1.251-.683-2.626-1.103-4.101-1.103-5.47 0-9.898 5.153-9.898 11.517 0 4.452 2.176 8.305 5.354 10.222L5.391 56.217c-.836.393-1.387 1.337-1.387 2.392v10.588c0 1.419.991 2.569 2.21 2.569h7.929v-11.11c0-3.237 1.802-6.172 4.599-7.481l10.262-4.779a20.2 20.2 0 01-1.051-1.89zm32.184-11.705h34.092V34.8l.006.001c.973 0 1.761-.789 1.761-1.761v-6.431c0-.973-.789-1.761-1.761-1.761l-.006.001v-.005H56.133a20.013 20.013 0 013.526 7.435c.215.889.371 1.72.478 2.522zm35.859 31.635c0-.973-.789-1.761-1.761-1.761l-.006.001v-.005H72.007v9.089c0 .293-.016.582-.045.867h22.267v-.001l.006.001c.973 0 1.761-.789 1.761-1.761v-6.43zm-1.761-21.674l-.006.001v-.005H58.944c-.159.419-.327.836-.514 1.249a20.258 20.258 0 01-1.224 2.297l10.288 4.908a7.67 7.67 0 012.078 1.503h24.657v-.001l.006.001c.973 0 1.761-.789 1.761-1.761v-6.431c0-.973-.789-1.761-1.761-1.761z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M65.323 57.702l-11.551-5.51-4.885-2.33c2.134-1.344 3.866-3.418 5-5.917a16.045 16.045 0 001.435-6.631c0-1.348-.213-2.627-.512-3.863-1.453-5.983-6.126-10.392-11.736-10.392-5.504 0-10.106 4.251-11.648 10.065-.356 1.333-.602 2.72-.602 4.189 0 2.552.596 4.93 1.609 7 1.171 2.4 2.906 4.379 5.018 5.651l-4.678 2.178-11.926 5.554c-1.037.485-1.717 1.654-1.717 2.959V73.76c0 1.756 1.224 3.181 2.735 3.181h42.417c1.511 0 2.735-1.424 2.735-3.181V60.656c.002-1.301-.668-2.458-1.694-2.954z"
  }));
});
ResultsDemographics.displayName = 'ResultsDemographics';
export var ResultsDemographicsDimensions = {
  height: 100,
  width: 100
};
